@@ -103,7 +103,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         renameActionB = new JButton("アクション名の変更");
         renameActionB.addActionListener(this);
         vBox.myAdd(renameActionB,0);
-        newActionB = new JButton("新しアクションを追加");
+        newActionB = new JButton("新しいアクションを追加");
         newActionB.addActionListener(this);
         vBox.myAdd(newActionB,0);
         newActionInputPanel = new NewActionInputPanel();
@@ -287,6 +287,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         rightBox.myAdd(Box.createVerticalGlue(),1);
 
         try {
+            Action3D.clearCash("x-res:///jp/sourceforge/acerola3d/a3panels/resources/measure.a3");
             measure = new Action3D("x-res:///jp/sourceforge/acerola3d/a3panels/resources/measure.a3");
             measure.setPickable(false);
             empty = new Action3D("x-res:///jp/sourceforge/acerola3d/a3editor/resources/empty.a3");
@@ -364,11 +365,12 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         for (A3eFile bvh : a3editor.fileManager.listA3eFile(A3eFileType.BVH)) {
             bvhCB.addItem(bvh);
         }
-        String bvh = actionEditor.getBVH();
-        if (bvh==null)
+        A3eFile bvh = actionEditor.getBVHFile();
+        if (bvh==null) {
             bvhCB.setSelectedItem(A3eFile.noneFile);
-        else
+        } else {
             bvhCB.setSelectedItem(bvh);
+        }
         bvhCB.addActionListener(this);
         loopCB.setSelected(actionEditor.getLoop());
         segnoL.setText(""+actionEditor.getSegno());
@@ -380,8 +382,8 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
         for (A3eFile sf : a3editor.fileManager.listA3eFile(A3eFileType.SOUND)) {
             soundFileCB.addItem(sf);
         }
-        String soundFile = actionEditor.getSoundFile();
-        if (soundFile!=null) {
+        A3eFile soundFile = actionEditor.getSoundFile();
+        if (!soundFile.equals(A3eFile.noneFile)) {
             soundFileCB.setSelectedItem(soundFile);
             soundTypeCB.setEnabled(true);
             soundLoopCB.setEnabled(true);
@@ -397,7 +399,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
             Quat4d q = Util.a2bQuat(new Vector3d(0.0,0.0,1.0),v);
             speaker.setQuat(q);
         } else {
-            soundFileCB.setSelectedItem("[none]");
+            soundFileCB.setSelectedItem(A3eFile.noneFile);
             soundTypeCB.setEnabled(false);
             soundLoopCB.setEnabled(false);
             soundGainB.setEnabled(false);
@@ -1017,7 +1019,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
                 actionEditor.updatePartsOffsetRotScale();
             } else if (m.equals("骨だけ")) {
                 actionEditor.updateActionOffsetRotScale();
-            } else if (m.equals("形全て")) {
+            } else if (m.equals("形すべて")) {
                 actionEditor.updatePartsOffsetRotScale();
             } else if (m.equals("一つの形")) {
                 String bn = (String)boneCB.getSelectedItem();
@@ -1054,7 +1056,7 @@ class A3eActionEditorGUI extends JPanel implements ActionListener {
                 v = Util.trans(q,new Vector3d(0.0,0.0,1.0));
                 actionEditor.setSoundDirection(v.x,v.y,v.z);
             } else {
-                System.out.println("???????");
+                System.out.println("???????"+m);
             }
         }
     }
